==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_login.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_login.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("LAN_27", "You left required field(s) blank");
define("LAN_300", "Incorrect login. The entered data doesn't match to a registered user. Check if you have the CAPS-LOCK key activated as logins on this site are case sensitive");
define("LAN_302", "You have not activated your account. You should have received an email with instructions on how to confirm your account. If not, please click <a href='".e_BASE."signup.php?resend'>here</a>.");
define("LAN_303", "Incorrect code entered.");
define("LAN_304", "That username/password combination is already in use.");
define("LAN_LOGIN_1", "User name");
define("LAN_LOGIN_2", "User password");
define("LAN_LOGIN_3", "Protected server");
define("LAN_LOGIN_4", "Please enter your details to gain access.");
define("LAN_LOGIN_5", "Click here to Sign-Up");
define("LAN_LOGIN_6", "Not accepting new members at this time");
define("LAN_LOGIN_7", "Enter visible code");
define("LAN_LOGIN_8", "Remember Me");
define("LAN_LOGIN_9", "Log In");
define("LAN_LOGIN_10", "Click to login");
define("LAN_LOGIN_11", "Register as a New User");
define("LAN_LOGIN_12", "Forgot Password");
define("LAN_LOGIN_13", "Please enter text in image");

define("LAN_LOGIN_14", "User attempted to login with unrecognised user name");
define("LAN_LOGIN_15", "User attempted to login with incorrect password");
define("LAN_LOGIN_16", "User attempted to login with username/password combination that was already in use");
define("LAN_LOGIN_17", "User password (hashed)");
define("LAN_LOGIN_18", "Auto-ban: More than 10 failed login attempts");
define("LAN_LOGIN_19", "> 10 failed login attempts");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_login.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_login.php $
|     $Revision: 11678 $
|     $Id: lan_login.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("LAN_27", "You left required field(s) blank");
define("LAN_300", "Incorrect login. The entered data doesn't match to a registered user. Check if you have the CAPS-LOCK key activated as logins on this site are case sensitive");
define("LAN_302", "You have not activated your account. You should have received an email with instructions on how to confirm your account. If not, please click <a href='".e_BASE."signup.php?resend'>here</a>.");
define("LAN_303", "Incorrect code entered.");
define("LAN_304", "That username/password combination is already in use.");
define("LAN_LOGIN_1", "User name");
define("LAN_LOGIN_2", "User password");
define("LAN_LOGIN_3", "Protected server");
define("LAN_LOGIN_4", "Please enter your details to gain access.");
define("LAN_LOGIN_5", "Click here to Sign-Up");
define("LAN_LOGIN_6", "Not accepting new members at this time");
define("LAN_LOGIN_7", "Enter visible code");
define("LAN_LOGIN_8", "Remember Me");
define("LAN_LOGIN_9", "Log In");
define("LAN_LOGIN_10", "Click to login");
define("LAN_LOGIN_11", "Register as a New User");
define("LAN_LOGIN_12", "Forgot Password");
define("LAN_LOGIN_13", "Please enter text in image");

define("LAN_LOGIN_14", "User attempted to login with unrecognised user name");
define("LAN_LOGIN_15", "User attempted to login with incorrect password");
define("LAN_LOGIN_16", "User attempted to login with username/password combination that was already in use");
define("LAN_LOGIN_17", "User password (hashed)");
define("LAN_LOGIN_18", "Auto-ban: More than 10 failed login attempts");
define("LAN_LOGIN_19", "> 10 failed login attempts");

?>
